@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.4.3"
+__version__ = "0.4.4"
 
 
 import datetime
@@ -116,8 +116,7 @@ class CuJiraX:
                 )
                 res = result.import_xray_json_results(req)
                 output.update({
-                    'import_status': res.status_code,
-                    'import_response': res.json()
+                    'import_status': res.status_code
                 })
         return output    
         
